==> snap-rcp-3.0.2-20160504.124053-9-sources.jar: org/esa/snap/rcp/actions/help/Bundle.java <==
package org.esa.snap.rcp.actions.help;
/** Localizable strings for {@link org.esa.snap.rcp.actions.help}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>Help</i>
     * @see HelpAction
     */
    static String CTL_HelpActionText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HelpActionText");
    }
    /**
     * @return <i>Invokes the help system.</i>
     * @see HelpAction
     */
    static String CTL_HelpActionToolTip() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HelpActionToolTip");
    }
    /**
     * @return <i>Report an Issue</i>
     * @see ReportIssueAction
     */
    static String CTL_ReportIssueAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ReportIssueAction_MenuText");
    }
    /**
     * @return <i>Opens a web page explaining how to report an issue</i>
     * @see ReportIssueAction
     */
    static String CTL_ReportIssueAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ReportIssueAction_ShortDescription");
    }
    /**
     * @return <i>SNAP Home Page</i>
     * @see ShowHomePageAction
     */
    static String CTL_ShowHomePageAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowHomePageAction_MenuText");
    }
    /**
     * @return <i>Browse the SNAP Toolboxes home page</i>
     * @see ShowHomePageAction
     */
    static String CTL_ShowHomePageAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowHomePageAction_ShortDescription");
    }
    /**
     * @return <i>Tutorials</i>
     * @see ShowTutorialsPageAction
     */
    static String CTL_ShowTutorialsPageAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowTutorialsPageAction_MenuText");
    }
    /**
     * @return <i>Browse the SNAP Toolboxes tutorials web page</i>
     * @see ShowTutorialsPageAction
     */
    static String CTL_ShowTutorialsPageAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowTutorialsPageAction_ShortDescription");
    }
    private void Bundle() {}
}

==> snap-rcp-5.0.8-20170727.054422-18-sources.jar: org/esa/snap/rcp/actions/help/Bundle.java <==
package org.esa.snap.rcp.actions.help;
/** Localizable strings for {@link org.esa.snap.rcp.actions.help}. */
@javax.annotation.Generated(value="org.netbeans.modules.openide.util.NbBundleProcessor")
class Bundle {
    /**
     * @return <i>Help</i>
     * @see HelpAction
     */
    static String CTL_HelpActionText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HelpActionText");
    }
    /**
     * @return <i>Invokes the help system.</i>
     * @see HelpAction
     */
    static String CTL_HelpActionToolTip() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_HelpActionToolTip");
    }
    /**
     * @return <i>Report an Issue</i>
     * @see ReportIssueAction
     */
    static String CTL_ReportIssueAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ReportIssueAction_MenuText");
    }
    /**
     * @return <i>Opens a web page explaining how to report an issue</i>
     * @see ReportIssueAction
     */
    static String CTL_ReportIssueAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ReportIssueAction_ShortDescription");
    }
    /**
     * @return <i>SNAP Home Page</i>
     * @see ShowHomePageAction
     */
    static String CTL_ShowHomePageAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowHomePageAction_MenuText");
    }
    /**
     * @return <i>Browse the SNAP Toolboxes home page</i>
     * @see ShowHomePageAction
     */
    static String CTL_ShowHomePageAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowHomePageAction_ShortDescription");
    }
    /**
     * @return <i>Show Log Directory</i>
     * @see ShowLogInExplorer
     */
    static String CTL_ShowLogFileInExplorerAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowLogFileInExplorerAction_MenuText");
    }
    /**
     * @return <i>Tutorials</i>
     * @see ShowTutorialsPageAction
     */
    static String CTL_ShowTutorialsPageAction_MenuText() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowTutorialsPageAction_MenuText");
    }
    /**
     * @return <i>Browse the SNAP Toolboxes tutorials web page</i>
     * @see ShowTutorialsPageAction
     */
    static String CTL_ShowTutorialsPageAction_ShortDescription() {
        return org.openide.util.NbBundle.getMessage(Bundle.class, "CTL_ShowTutorialsPageAction_ShortDescription");
    }
    private Bundle() {}
}
